--[[
 Adibags - Ren's Filters: Fishing - groups fishing items into an AdiBags group
--]]

local addonName, addon = ...
-- Get reference to AdiBags addon
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")
-- Register this addon with AdiBags
local fishing_filter = AdiBags:RegisterFilter("AdiBags_RensFilters_Fishing", 80)

-- Localization variable
local L = addon.L
-- xpacs with a value lower than this value are "legacy" fishing items
local current_xpac = 8
-- Table of xpac values to use as keys to look up values in the fishing_items table
local xpac_keys = {}

-- Name that is displayed in list of Filters
fishing_filter.uiName = L["name"]
-- Description displayed in configuration detail panel
fishing_filter.uiDesc = L["desc"]

-- Checks to see if this item is in a filter and returns the filter's
-- group title if so.
function fishing_filter:Filter(item)
  -- if the item we're checking is a fishing item
  if addon.fishing_items[item.itemId] then
    xpac = addon.fishing_items[item.itemId]["xpac"]
    -- if the fishing item we're checking is in an xpac that is in the key list
    if xpac == 99 or xpac_keys[xpac] then
      -- if this is a legacy item and legacy items are to be displayed separately
      if self.db.profile.separate_legacy and xpac < current_xpac then
        if self.db.profile.separate_quest and addon.fishing_items[item.itemId]["type"] == "turn" then
          return L["legacy_quest_title"]
        elseif self.db.profile.separate_reward and addon.fishing_items[item.itemId]["type"] == "reward" then
          return L["legacy_reward_title"]
        else
          return L["legacy_fishing_title"]
        end
      -- this was not a legacy item, so use the normal titles
      elseif self.db.profile.separate_quest and addon.fishing_items[item.itemId]["type"] == "turn" then
        return L["quest_title"]
      elseif self.db.profile.separate_reward and addon.fishing_items[item.itemId]["type"] == "reward" then
        return L["reward_title"]
      else
        return L["fishing_title"]
      end
    end
  end
end

-- Sets the table of expansion pack keys to the values selected by the user's options
local function SetXpacKeys(self)
  xpac_keys[1] = true
  xpac_keys[2] = true
  xpac_keys[3] = true
  xpac_keys[4] = true
  xpac_keys[5] = self.db.profile.include_mop
  xpac_keys[6] = self.db.profile.include_wod
  xpac_keys[7] = self.db.profile.include_leg
  xpac_keys[8] = self.db.profile.include_bfa
end

-- Initializes this addon; only called when WoW is started
function fishing_filter:OnInitialize()
  self.db = AdiBags.db:RegisterNamespace("AdiBags_RensFilters_Fishing", {
    profile = {
       include_mop = true,
       include_wod = true,
       include_leg = true,
       include_bfa = true,
       separate_quest = false,
       separate_reward = false,
       separate_legacy = false
    }
  })
  SetXpacKeys(self)
  AdiBags:Print("Adibags - Ren's Filters: Fishing loaded")
end

-- Returns options for AdiBags to display, if any (there are no options for this addon)
function fishing_filter:GetOptions()
  return {
    fishing_options = {
      name = L["expansions"],
      type = 'group',
      inline = true,
      order = 10,
      args = {
        include_mop = {
          name = L["name5"],
          desc = L["desc5"],
          type = 'toggle',
          order = 80,
        },
        include_wod = {
          name = L["name6"],
          desc = L["desc6"],
          type = 'toggle',
          order = 70,
        },
        include_leg = {
          name = L["name7"],
          desc = L["desc7"],
          type = 'toggle',
          order = 60,
        },
        include_bfa = {
          name = L["name8"],
          desc = L["desc8"],
          type = 'toggle',
          order = 50,
        },
      }
    },
    separate_quest = {
      name = L["quest_name"],
      desc = L["quest_name"],
      type = 'toggle',
      order = 20,
    },
    separate_reward = {
      name = L["reward_name"],
      desc = L["reward_desc"],
      type = 'toggle',
      order = 30,
    },
    separate_legacy = {
      name = L["leg_name"],
      desc = L["leg_desc"],
      type = 'toggle',
      order = 40,
    },
  },
  -- Notifies AdiBags to update itself for changed options
  AdiBags:GetOptionHandler(self, false, function()
    return self:Update()
  end)
end

-- Notifies AdiBags that it needs to update itself
function fishing_filter:Update()
  -- update the xpac keys for any change
  SetXpacKeys(self)
  self:SendMessage("AdiBags_FiltersChanged")
end

-- Notifies AdiBags that this addon is enabled
function fishing_filter:OnEnable()
  AdiBags:UpdateFilters()
end

-- Notifies AdiBags that this addon is disabled
function fishing_filter:OnDisable()
  AdiBags:UpdateFilters()
end
